# coding=utf-8
r"""
This code was generated by
\ / _    _  _|   _  _
 | (_)\/(_)(_|\/| |(/_  v1.0.0
      /       /
"""

from tests import IntegrationTestCase
from tests.holodeck import Request
from twilio.base.exceptions import TwilioException
from twilio.http.response import Response


class SettingsUpdateTestCase(IntegrationTestCase):

    def test_list_request(self):
        self.holodeck.mock(Response(500, ''))

        with self.assertRaises(TwilioException):
            self.client.supersim.v1.settings_updates.list()

        self.holodeck.assert_has_request(Request(
            'get',
            'https://supersim.twilio.com/v1/SettingsUpdates',
        ))

    def test_read_empty_response(self):
        self.holodeck.mock(Response(
            200,
            '''
            {
                "settings_updates": [],
                "meta": {
                    "page": 0,
                    "page_size": 50,
                    "first_page_url": "https://supersim.twilio.com/v1/SettingsUpdates?PageSize=50&Page=0",
                    "previous_page_url": null,
                    "url": "https://supersim.twilio.com/v1/SettingsUpdates?PageSize=50&Page=0",
                    "next_page_url": null,
                    "key": "settings_updates"
                }
            }
            '''
        ))

        actual = self.client.supersim.v1.settings_updates.list()

        self.assertIsNotNone(actual)

    def test_read_sim_only_response(self):
        self.holodeck.mock(Response(
            200,
            '''
            {
                "settings_updates": [
                    {
                        "sid": "OBaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                        "iccid": "89883070000123456789",
                        "sim_sid": "HSaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                        "status": "successful",
                        "packages": [
                            {
                                "name": "base-settings",
                                "version": "1.0.0",
                                "more_info": "https://twilio.com/docs/iot/supersim/settings-packages/base-settings"
                            }
                        ],
                        "date_completed": "2015-07-30T20:00:00Z",
                        "date_created": "2015-07-30T20:00:00Z",
                        "date_updated": "2015-07-30T20:00:00Z"
                    }
                ],
                "meta": {
                    "page": 0,
                    "page_size": 50,
                    "first_page_url": "https://supersim.twilio.com/v1/SettingsUpdates?Sim=HSaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa&PageSize=50&Page=0",
                    "previous_page_url": null,
                    "url": "https://supersim.twilio.com/v1/SettingsUpdates?Sim=HSaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa&PageSize=50&Page=0",
                    "next_page_url": null,
                    "key": "settings_updates"
                }
            }
            '''
        ))

        actual = self.client.supersim.v1.settings_updates.list()

        self.assertIsNotNone(actual)

    def test_read_status_only_response(self):
        self.holodeck.mock(Response(
            200,
            '''
            {
                "settings_updates": [
                    {
                        "sid": "OBaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                        "iccid": "89883070000123456789",
                        "sim_sid": "HSaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                        "status": "scheduled",
                        "packages": [
                            {
                                "name": "base-settings",
                                "version": "1.0.0",
                                "more_info": "https://twilio.com/docs/iot/supersim/settings-packages/base-settings"
                            }
                        ],
                        "date_completed": null,
                        "date_created": "2015-07-30T20:00:00Z",
                        "date_updated": "2015-07-30T20:00:00Z"
                    }
                ],
                "meta": {
                    "page": 0,
                    "page_size": 50,
                    "first_page_url": "https://supersim.twilio.com/v1/SettingsUpdates?Status=scheduled&PageSize=50&Page=0",
                    "previous_page_url": null,
                    "url": "https://supersim.twilio.com/v1/SettingsUpdates?Status=scheduled&PageSize=50&Page=0",
                    "next_page_url": null,
                    "key": "settings_updates"
                }
            }
            '''
        ))

        actual = self.client.supersim.v1.settings_updates.list()

        self.assertIsNotNone(actual)

    def test_read_full_response(self):
        self.holodeck.mock(Response(
            200,
            '''
            {
                "settings_updates": [
                    {
                        "sid": "OBaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                        "iccid": "89883070000123456789",
                        "sim_sid": "HSaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
                        "status": "scheduled",
                        "packages": [
                            {
                                "name": "base-settings",
                                "version": "1.0.0",
                                "more_info": "https://twilio.com/docs/iot/supersim/settings-packages/base-settings"
                            }
                        ],
                        "date_completed": null,
                        "date_created": "2015-07-30T20:00:00Z",
                        "date_updated": "2015-07-30T20:00:00Z"
                    }
                ],
                "meta": {
                    "page": 0,
                    "page_size": 50,
                    "first_page_url": "https://supersim.twilio.com/v1/SettingsUpdates?Status=scheduled&Sim=HSaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa&PageSize=50&Page=0",
                    "previous_page_url": null,
                    "url": "https://supersim.twilio.com/v1/SettingsUpdates?Status=scheduled&Sim=HSaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa&PageSize=50&Page=0",
                    "next_page_url": null,
                    "key": "settings_updates"
                }
            }
            '''
        ))

        actual = self.client.supersim.v1.settings_updates.list()

        self.assertIsNotNone(actual)
